Learn R Programming

psSubpathway (version 0.1.0)

ssgsea: psSubpathway internal functions

Description

Single sample GSEA calculates a gene set enrichment score per sample as the normalized difference in empirical cumulative distribution functions of gene expression ranks inside and outside the gene set.

Usage

SubSEA

Arguments

Details

ssgsea